@@ -1,8 +1,9 @@
 # Copyright (c) OpenMMLab. All rights reserved.
 from .base import BaseFileHandler
 from .json_handler import JsonHandler
+from .jsons_handler import JsonsHandler
 from .pickle_handler import PickleHandler
 from .yaml_handler import YamlHandler
 from .csv_handler import CsvHandler
 
-__all__ = ['BaseFileHandler', 'JsonHandler', 'PickleHandler', 'YamlHandler','CsvHandler']
+__all__ = ['BaseFileHandler', 'JsonHandler','JsonsHandler', 'PickleHandler', 'YamlHandler','CsvHandler']
